@@ -4,6 +4,7 @@ from apache_beam.transforms.window import GlobalWindow
 from apache_beam.transforms import PTransform, ParDo, DoFn
 import google.cloud.storage as storage
 import pandas as pd
+import pickle
 
 
 def upload_blob(bucket_name, source_file_name, destination_blob_name):
@@ -14,6 +15,15 @@ def upload_blob(bucket_name, source_file_name, destination_blob_name):
     blob.upload_from_filename(source_file_name)
 
 
+def download_blob(bucket_name, source_file, destination_file):
+    storage_client = storage.Client()
+    bucket = storage_client.get_bucket(bucket_name)
+    blob = bucket.blob(source_file)
+    blob.download_to_filename(destination_file)
+
+    print('File {} downloaded to {}.'.format(source_file, destination_file))
+
+
 class _BatchingFn(DoFn):
 
     def __init__(self, batch_size=500):
@@ -53,118 +63,106 @@ class BatchingFn(PTransform):
 
 class _CreateCategoricalEncodedVariables(DoFn):
 
-    def __init__(self,
-                 equipment_mlb,
-                 email_transforms,
-                 state_transforms,
-                 city_transforms,
-                 zip_code_transforms,
-                 dot_transforms,
-                 channel_transforms,
-                 hos_cycle_transforms,
-                 hos_home_timezone_transforms,
-                 mc_number_transforms,
-                 user_type_transforms,
-                 safety_rating_transforms):
-        super(_CreateCategoricalEncodedVariables, self).__init__()
-        self.equipment_mlb = equipment_mlb
-        self.state_transforms = state_transforms
-        self.city_transforms = city_transforms
-        self.email_transforms = email_transforms
-        self.zip_code_transforms = zip_code_transforms
-        self.dot_transforms = dot_transforms
-        self.channel_transforms = channel_transforms
-        self.hos_cycle_transforms = hos_cycle_transforms
-        self.hos_home_timezone_transforms = hos_home_timezone_transforms
-        self.mc_number_transforms = mc_number_transforms
-        self.user_type_transforms = user_type_transforms
-        self.safety_rating_transforms = safety_rating_transforms
 
     def process(self, data):
         # Multi Label Binarizer Variables
         # Split out Equipment Types
 
+        equipment_mlb = pickle.load(download_blob("user_transforms", "load_equipment_mlb.pkl", "load_equipment_mlb.pkl"))
+        state_lbe = pickle.load(download_blob("user_transforms", "user_state_lbe.pkl", "user_state_lbe.pkl"))
+        state_ohe = pickle.load(download_blob("user_transforms", "user_state_ohe.pkl", "user_state_ohe.pkl"))
+        city_lbe = pickle.load(download_blob("user_transforms", "user_city_lbe.pkl", "user_city_lbe.pkl"))
+        city_ohe = pickle.load(download_blob("user_transforms", "user_city_ohe.pkl", "user_city_ohe.pkl"))
+        email_lbe = pickle.load(download_blob("user_transforms", "user_email_lbe.pkl", "user_email_lbe.pkl"))
+        email_ohe = pickle.load(download_blob("user_transforms", "user_email_ohe.pkl", "user_email_ohe.pkl"))
+        zip_code_lbe = pickle.load(download_blob("user_transforms", "user_zip_code_lbe.pkl", "user_zip_code_lbe.pkl"))
+        zip_code_ohe = pickle.load(download_blob("user_transforms", "user_zip_code_ohe.pkl", "user_zip_code_ohe.pkl"))
+        channel_lbe = pickle.load(download_blob("user_transforms", "user_channel_lbe.pkl", "user_channel_lbe.pkl"))
+        channel_ohe = pickle.load(download_blob("user_transforms", "user_channel_ohe.pkl", "user_channel_ohe.pkl"))
+        dot_lbe = pickle.load(download_blob("user_transforms", "user_dot_lbe.pkl", "user_dot_lbe.pkl"))
+        dot_ohe = pickle.load(download_blob("user_transforms", "user_dot_ohe.pkl", "user_dot_ohe.pkl"))
+        hos_home_timezone_lbe = pickle.load(
+            download_blob("user_transforms", "user_hos_home_timezone_lbe.pkl", "user_hos_home_timezone_lbe.pkl"))
+        hos_home_timezone_ohe = pickle.load(
+            download_blob("user_transforms", "user_hos_home_timezone_ohe.pkl", "user_hos_home_timezone_ohe.pkl"))
+        hos_cycle_lbe = pickle.load(
+            download_blob("user_transforms", "user_hos_cycle_lbe.pkl", "user_hos_cycle_lbe.pkl"))
+        hos_cycle_ohe = pickle.load(
+            download_blob("user_transforms", "user_hos_cycle_ohe.pkl", "user_hos_cycle_ohe.pkl"))
+        mc_number_lbe = pickle.load(
+            download_blob("user_transforms", "user_mc_number_lbe.pkl", "user_mc_number_lbe.pkl"))
+        mc_number_ohe = pickle.load(
+            download_blob("user_transforms", "user_mc_number_ohe.pkl", "user_mc_number_ohe.pkl"))
+        user_type_lbe = pickle.load(
+            download_blob("user_transforms", "user_user_type_lbe.pkl", "user_user_type_lbe.pkl"))
+        user_type_ohe = pickle.load(
+            download_blob("user_transforms", "user_user_type_ohe.pkl", "user_user_type_ohe.pkl"))
+        safety_rating_lbe = pickle.load(
+            download_blob("user_transforms", "user_safety_rating_lbe.pkl", "user_safety_rating_lbe.pkl"))
+        safety_rating_ohe = pickle.load(
+            download_blob("user_transforms", "user_safety_rating_ohe.pkl", "user_safety_rating_ohe.pkl"))
+
         df = pd.DataFrame(data)
         df.equipment_types.fillna(value=u'', inplace=True)
         df["equipment_types"] = df["equipment_types"].str.split(pat=", ")
-        df["equipment_types_encoded"] = list(self.equipment_mlb.transform(df["equipment_types"]))
+        df["equipment_types_encoded"] = list(equipment_mlb.transform(df["equipment_types"]))
         df.drop("equipment_types", axis=1, inplace=True)
 
         # Split out Predicted Equipment Types
         df.predicted_equipment_types.fillna(value=u'', inplace=True)
         df["predicted_equipment_types"] = df["predicted_equipment_types"].str.split(pat=", ")
-        df["predicted_equipment_types_encoded"] = list(self.equipment_mlb.transform(df["predicted_equipment_types"]))
+        df["predicted_equipment_types_encoded"] = list(equipment_mlb.transform(df["predicted_equipment_types"]))
         df.drop("predicted_equipment_types", axis=1, inplace=True)
 
         # One Hot Encode Variables
         # State
-        state_lbe = self.state_transforms[0]
-        state_ohe = self.state_transforms[1]
         state_encoded = state_lbe.transform(df['state'])
         data = state_ohe.transform(state_encoded.reshape(-1, 1))
         df["state_encoded"] = list(data)
         df.drop("state", axis=1, inplace=True)
 
         # City
-        city_lbe = self.city_transforms[0]
-        city_ohe = self.city_transforms[1]
         city_encoded = city_lbe.transform(df['city'])
         df["city_encoded"] = list(city_ohe.transform(city_encoded.reshape(-1, 1)))
         df.drop("city", axis=1, inplace=True)
 
         # Zip Code
-        zip_code_lbe = self.zip_code_transforms[0]
-        zip_code_ohe = self.zip_code_transforms[1]
         zip_code_encoded = zip_code_lbe.transform(df['zip_code'])
         df["zip_code_encoded"] = list(zip_code_ohe.transform(zip_code_encoded.reshape(-1, 1)))
         df.drop("zip_code", axis=1, inplace=True)
 
         # Email
-        email_lbe = self.email_transforms[0]
-        email_ohe = self.email_transforms[1]
         email_encoded = email_lbe.transform(df['email'])
         df["email_encoded"] = list(email_ohe.transform(email_encoded.reshape(-1, 1)))
         df.drop("email", axis=1, inplace=True)
 
         # DOT
-        dot_lbe = self.dot_transforms[0]
-        dot_ohe = self.dot_transforms[1]
         dot_encoded = dot_lbe.transform(df['dot'])
         df["dot_encoded"] = list(dot_ohe.transform(dot_encoded.reshape(-1, 1)))
         df.drop("dot", axis=1, inplace=True)
 
         # Channel
-        channel_lbe = self.channel_transforms[0]
-        channel_ohe = self.channel_transforms[1]
         channel_encoded = channel_lbe.transform(df['channel'])
         df["channel_encoded"] = list(channel_ohe.transform(channel_encoded.reshape(-1, 1)))
         df.drop("channel", axis=1, inplace=True)
 
         # hos_cycle
-        hos_cycle_lbe = self.hos_cycle_transforms[0]
-        hos_cycle_ohe = self.hos_cycle_transforms[1]
         hos_cycle_encoded = hos_cycle_lbe.transform(df['hos_cycle'])
         df["hos_cycle_encoded"] = list(hos_cycle_ohe.transform(hos_cycle_encoded.reshape(-1, 1)))
         df.drop("hos_cycle", axis=1, inplace=True)
 
         # hos_home_timezone
-        hos_home_timezone_lbe = self.hos_home_timezone_transforms[0]
-        hos_home_timezone_ohe = self.hos_home_timezone_transforms[1]
         hos_home_timezone_encoded = hos_home_timezone_lbe.transform(df['hos_home_timezone'])
         df["hos_home_timezone_encoded"] = list(
             hos_home_timezone_ohe.transform(hos_home_timezone_encoded.reshape(-1, 1)))
         df.drop("hos_home_timezone", axis=1, inplace=True)
 
         # mc_number
-        mc_number_lbe = self.mc_number_transforms[0]
-        mc_number_ohe = self.mc_number_transforms[1]
         mc_number_encoded = mc_number_lbe.transform(df['mc_number'])
         df["mc_number_encoded"] = list(mc_number_ohe.transform(mc_number_encoded.reshape(-1, 1)))
         df.drop("mc_number", axis=1, inplace=True)
 
         # user_type
-        user_type_lbe = self.user_type_transforms[0]
-        user_type_ohe = self.user_type_transforms[1]
         user_type_encoded = user_type_lbe.transform(df['user_type'])
         df["user_type_encoded"] = list(user_type_ohe.transform(user_type_encoded.reshape(-1, 1)))
         df.drop("user_type", axis=1, inplace=True)
@@ -387,8 +385,6 @@ class _CreateCategoricalEncodedVariables(DoFn):
         df["common_lane_5_dropoff_city_encoded"] = list(data)
         df.drop("common_lane_5_dropoff_city", axis=1, inplace=True)
 
-        safety_rating_lbe = self.safety_rating_transforms[0]
-        safety_rating_ohe = self.safety_rating_transforms[1]
         safety_rating_encoded = safety_rating_lbe.transform(df['safer_result_safety_rating'])
         df["safer_result_safety_rating_encoded"] = list(safety_rating_ohe.transform(safety_rating_encoded.reshape(-1, 1)))
         df.drop("safer_result_safety_rating", axis=1, inplace=True)
@@ -398,46 +394,8 @@ class _CreateCategoricalEncodedVariables(DoFn):
 
 class CreateCategoricalEncodedVariables(PTransform):
 
-    def __init__(self,
-                 equipment_mlb,
-                 email_transforms,
-                 state_transforms,
-                 city_transforms,
-                 zip_code_transforms,
-                 dot_transforms,
-                 channel_transforms,
-                 hos_cycle_transforms,
-                 hos_home_timezone_transforms,
-                 mc_number_transforms,
-                 user_type_transforms,
-                 safety_rating_transforms):
-        super(CreateCategoricalEncodedVariables, self).__init__()
-        self.equipment_mlb = equipment_mlb
-        self.state_transforms = state_transforms
-        self.city_transforms = city_transforms
-        self.email_transforms = email_transforms
-        self.zip_code_transforms = zip_code_transforms
-        self.dot_transforms = dot_transforms
-        self.channel_transforms = channel_transforms
-        self.hos_cycle_transforms = hos_cycle_transforms
-        self.hos_home_timezone_transforms = hos_home_timezone_transforms
-        self.mc_number_transforms = mc_number_transforms
-        self.user_type_transforms = user_type_transforms
-        self.safety_rating_transforms = safety_rating_transforms
-
     def expand(self, pcoll):
-        return pcoll | ParDo(_CreateCategoricalEncodedVariables(self.equipment_mlb,
-                                                                self.email_transforms,
-                                                                self.state_transforms,
-                                                                self.city_transforms,
-                                                                self.zip_code_transforms,
-                                                                self.dot_transforms,
-                                                                self.channel_transforms,
-                                                                self.hos_cycle_transforms,
-                                                                self.hos_home_timezone_transforms,
-                                                                self.mc_number_transforms,
-                                                                self.user_type_transforms,
-                                                                self.safety_rating_transforms))
+        return pcoll | ParDo(_CreateCategoricalEncodedVariables())
 
 
 class _SaveDataframeToGCS(DoFn):
